Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(413)

Unified Diff: chrome/test/ui/ppapi_uitest.h

Issue 10409032: Enable PPAPINaCl GLIBC browser_tests. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rename newlib nmf file Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/test/ui/ppapi_uitest.h
diff --git a/chrome/test/ui/ppapi_uitest.h b/chrome/test/ui/ppapi_uitest.h
index da9e3d5cb1ae2aa00dc59209b85b3f367a52da51..6f99cec4af92128bcf26ed5c8a02a446c3f46591 100644
--- a/chrome/test/ui/ppapi_uitest.h
+++ b/chrome/test/ui/ppapi_uitest.h
@@ -68,10 +68,21 @@ class OutOfProcessPPAPITest : public PPAPITest {
virtual void SetUpCommandLine(CommandLine* command_line) OVERRIDE;
};
-// NaCl plugin test runner.
-class PPAPINaClTest : public PPAPITestBase {
+// NaCl plugin test runner for Newlib runtime.
+class PPAPINaClNewlibTest : public PPAPITestBase {
public:
- PPAPINaClTest();
+ PPAPINaClNewlibTest();
+
+ virtual void SetUpCommandLine(CommandLine* command_line) OVERRIDE;
+
+ virtual std::string BuildQuery(const std::string& base,
+ const std::string& test_case) OVERRIDE;
+};
+
+// NaCl plugin test runner for GNU-libc runtime.
+class PPAPINaClGLibcTest : public PPAPITestBase {
+ public:
+ PPAPINaClGLibcTest();
virtual void SetUpCommandLine(CommandLine* command_line) OVERRIDE;

Powered by Google App Engine
This is Rietveld 408576698